package me.Demon.DemonLevels.util;

import me.Demon.DemonLevels.manage.MobsManage;
import me.Demon.DemonPlugin.DemonAPI;
import org.bukkit.Bukkit;
import org.bukkit.configuration.ConfigurationSection;
import org.bukkit.configuration.file.FileConfiguration;

import java.io.File;
import java.io.IOException;
import java.util.*;

public class ConfigYml {

    private File file;
    private FileConfiguration configuration;
    private TreeMap<Integer,String> rankTitleMap = new TreeMap<>();
    private HashMap<String, MobsManage> manageHashMap = new HashMap<>();
    private List<Map.Entry<String, Integer>> levelNeedExpFormat = new ArrayList<>();

    public ConfigYml(File file,FileConfiguration yml){
        this.file = file;
        this.configuration = yml;
        loadRankTitle(yml);
        loadMobExperienceManagement(yml);
        loadNeedExpFormat(yml);
    }

    public void loadMobExperienceManagement(FileConfiguration yml){
        ConfigurationSection section = yml.getConfigurationSection("MobKillExp");
        if(section == null){
            System.out.println("[错误报告] MobKillExp 配置不存在.");
            return;
        }
        for (String mmKey : section.getKeys(false)){
            manageHashMap.put(mmKey,new MobsManage(mmKey,yml));
        }
        DemonAPI.sendConsoleMessage("§f[§a!§f] §fMm怪经验 §8> §6"+manageHashMap.size()+"个");
    }

    public void setKillsExp(String mmKey,int max){
        configuration.set("MobKillExp."+mmKey,max);
        saveFile();
        manageHashMap.put(mmKey,new MobsManage(mmKey,configuration));
    }
    public void setKillsExp(String mmKey,int min,int max){
        configuration.set("MobKillExp."+mmKey,min+"~"+max);
        saveFile();
        manageHashMap.put(mmKey,new MobsManage(mmKey,configuration));
    }

    public MobsManage getMobsManage(String mmKey){
        if(this.manageHashMap.get(mmKey) != null){
            return this.manageHashMap.get(mmKey);
        }
        return null;
    }

    public void loadRankTitle(FileConfiguration yml){
        ConfigurationSection section = yml.getConfigurationSection("CustonName");
        if(section == null){
            System.out.println("[错误报告] CustonName 配置不存在.");
            return;
        }
        for (String levelKey : section.getKeys(false)){
            int level = Integer.parseInt(levelKey);
            String title = section.getString(levelKey);
            if(title != null){
                rankTitleMap.put(level,title);
            }
        }
        DemonAPI.sendConsoleMessage("§f[§a!§f] §f境界称号 §8> §6"+rankTitleMap.size()+"个");
    }

    public String getRankTitle(int level) {
        Map.Entry<Integer, String> entry = rankTitleMap.floorEntry(level);
        if (entry != null) {
            return entry.getValue();
        }
        return "§7器士";
    }


    public void loadNeedExpFormat(FileConfiguration yml){
        ConfigurationSection section = yml.getConfigurationSection("NeelUpExp");
        if(section == null){
            System.out.println("[错误报告] NeelUpExp 配置不存在.");
            return;
        }
        HashMap<String,Integer> stringHashMap = new HashMap<>();
        for (String levelKey : section.getKeys(false)){
            int level = Integer.parseInt(levelKey);
            String expFormat = section.getString(levelKey).replace(" ","");
            stringHashMap.put(expFormat,level);
        }
        List<Map.Entry<String,Integer>> entryArrayList = new ArrayList<>(stringHashMap.entrySet());
        entryArrayList.sort((o1, o2) -> o2.getValue().compareTo(o1.getValue()));
        this.levelNeedExpFormat = entryArrayList;
        DemonAPI.sendConsoleMessage("§f[§a!§f] §f自定义经验 §8> §6"+levelNeedExpFormat.size()+"条");
    }

    public List<Map.Entry<String, Integer>> getLevelNeedExpFormat() {
        return levelNeedExpFormat;
    }

    public void saveFile(){
        try {
            this.configuration.save(this.file);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
